@@ -46,7 +46,7 @@ class IntegratedGradients(WhiteBoxExplainer):
 
     def __init__(self,
                  model: tf.keras.Model,
-                 output_layer: Optional[Union[str, int]] = -1,
+                 output_layer: Optional[Union[str, int]] = None,
                  batch_size: Optional[int] = 32,
                  steps: int = 50,
                  baseline_value: float = .0):
